# Changelog

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),

## [Unreleased]

## [0.1.0]

### Added

- list and dict supported now

### Changed

- `ConfigParser` cleaned up

## [0.0.2]

### Changed

- `README.md` updated

## [0.0.1]

### Added

- project init
